@@ -37,7 +37,7 @@ mv -f /usr/lib/udev/rules.d/95-ceph-osd.rules /usr/lib/udev/rules.d/95-ceph-osd.
 ",
        'onlyif'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
-DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1}}')
+DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1} else { print 0 } }')
 test -f /usr/lib/udev/rules.d/95-ceph-osd.rules && test \$DISABLE_UDEV -eq 1
 ",
        'logoutput' => true,
@@ -76,7 +76,7 @@ if ! test -b $disk ; then
     fi
 fi
 # activate happens via udev when using the entire device
-if ! test -b $disk || ! test -b ${disk}1 || ! test -b ${disk}p1 ; then
+if ! test -b \$disk && ! ( test -b \${disk}1 || test -b \${disk}p1 ); then
   ceph-disk activate $disk || true
 fi
 if test -f /usr/lib/udev/rules.d/95-ceph-osd.rules.disabled && ( test -b ${disk}1 || test -b ${disk}p1 ); then
@@ -85,6 +85,7 @@ fi
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
+ceph-disk list | egrep \" *(\${disk}1?|\${disk}p1?) .*ceph data, active\" ||
 ls -ld /var/lib/ceph/osd/ceph-* | grep \" $(readlink -f /srv)\$\"
 ",
         'logoutput' => true
@@ -113,7 +114,7 @@ mv -f /usr/lib/udev/rules.d/95-ceph-osd.rules /usr/lib/udev/rules.d/95-ceph-osd.
 ",
        'onlyif'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
-DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1}}')
+DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1} else { print 0 } }')
 test -f /usr/lib/udev/rules.d/95-ceph-osd.rules && test \$DISABLE_UDEV -eq 1
 ",
        'logoutput' => true,
@@ -163,7 +164,7 @@ if ! test -b $disk ; then
     fi
 fi
 # activate happens via udev when using the entire device
-if ! test -b $disk || ! test -b ${disk}1 || ! test -b ${disk}p1 ; then
+if ! test -b \$disk && ! ( test -b \${disk}1 || test -b \${disk}p1 ); then
   ceph-disk activate $disk || true
 fi
 if test -f /usr/lib/udev/rules.d/95-ceph-osd.rules.disabled && ( test -b ${disk}1 || test -b ${disk}p1 ); then
@@ -172,6 +173,7 @@ fi
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
+ceph-disk list | egrep \" *(\${disk}1?|\${disk}p1?) .*ceph data, active\" ||
 ls -ld /var/lib/ceph/osd/testcluster-* | grep \" $(readlink -f /srv/data)\$\"
 ",
         'logoutput' => true
@@ -192,7 +194,7 @@ mv -f /usr/lib/udev/rules.d/95-ceph-osd.rules /usr/lib/udev/rules.d/95-ceph-osd.
 ",
        'onlyif'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
-DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1}}')
+DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1} else { print 0 } }')
 test -f /usr/lib/udev/rules.d/95-ceph-osd.rules && test \$DISABLE_UDEV -eq 1
 ",
        'logoutput' => true,
@@ -231,7 +233,7 @@ if ! test -b $disk ; then
     fi
 fi
 # activate happens via udev when using the entire device
-if ! test -b $disk || ! test -b ${disk}1 || ! test -b ${disk}p1 ; then
+if ! test -b \$disk && ! ( test -b \${disk}1 || test -b \${disk}p1 ); then
   ceph-disk activate $disk || true
 fi
 if test -f /usr/lib/udev/rules.d/95-ceph-osd.rules.disabled && ( test -b ${disk}1 || test -b ${disk}p1 ); then
@@ -240,6 +242,7 @@ fi
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
+ceph-disk list | egrep \" *(\${disk}1?|\${disk}p1?) .*ceph data, active\" ||
 ls -ld /var/lib/ceph/osd/ceph-* | grep \" $(readlink -f /dev/nvme0n1)\$\"
 ",
         'logoutput' => true
@@ -260,7 +263,7 @@ mv -f /usr/lib/udev/rules.d/95-ceph-osd.rules /usr/lib/udev/rules.d/95-ceph-osd.
 ",
        'onlyif'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
-DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1}}')
+DISABLE_UDEV=$(ceph --version | awk 'match(\$3, /[0-9]+\\.[0-9]+/) {if (substr(\$3, RSTART, RLENGTH) <= 0.94) {print 1} else { print 0 } }')
 test -f /usr/lib/udev/rules.d/95-ceph-osd.rules && test \$DISABLE_UDEV -eq 1
 ",
        'logoutput' => true,
@@ -299,7 +302,7 @@ if ! test -b $disk ; then
     fi
 fi
 # activate happens via udev when using the entire device
-if ! test -b $disk || ! test -b ${disk}1 || ! test -b ${disk}p1 ; then
+if ! test -b \$disk && ! ( test -b \${disk}1 || test -b \${disk}p1 ); then
   ceph-disk activate $disk || true
 fi
 if test -f /usr/lib/udev/rules.d/95-ceph-osd.rules.disabled && ( test -b ${disk}1 || test -b ${disk}p1 ); then
@@ -308,6 +311,7 @@ fi
 ",
         'unless'    => "/bin/true # comment to satisfy puppet syntax requirements
 set -ex
+ceph-disk list | egrep \" *(\${disk}1?|\${disk}p1?) .*ceph data, active\" ||
 ls -ld /var/lib/ceph/osd/ceph-* | grep \" $(readlink -f /dev/cciss/c0d0)\$\"
 ",
         'logoutput' => true
